@@ -18,5 +18,7 @@ __all__ = [
 ]
 
 
-name = "make_vcard"
+__name__ = "make_vcard"
+__author__ = "antianshi"
+__version__ = "0.1.3"
 
