@@ -6,6 +6,9 @@ from .globals import SHEET, VCARD
 
 
 def read_file_xlsx_data(fn):
+    '''
+    fn == 输入文件名
+    '''
     global SHEET
     assert os.path.isfile(fn), "文件不存在"
 
@@ -47,7 +50,8 @@ def read_file_xlsx_data(fn):
                 continue
 
             data_one[k] = r[n].value
-        yield data_one
+        yield data_one 
+
 
 
 def read_file_csv_data(fn):
